@@ -31,6 +31,7 @@ namespace metaproxy_1 {
         class FrontendNet : public Base {
             class Rep;
             class Port;
+            class IP_Pattern;
             class ZAssocServer;
             class ZAssocChild;
             class ThreadPoolPackage;
@@ -42,6 +43,7 @@ namespace metaproxy_1 {
             void process(metaproxy_1::Package & package) const;
             void configure(const xmlNode * ptr, bool test_only,
                            const char *path);
+            void start() const;
             void stop(int signo) const;
         public:
             /// set ports
